import { z } from "zod";
import { CamperDisplayNameSchema, CamperHandleSchema, ColorStringSchema, EmailStringSchema, PronounStringSchema, TaglineStringSchema, TimestampStringSchema, URLStringSchema, } from "./branded-primitives";
export var CamperAccessLevel;
(function (CamperAccessLevel) {
    CamperAccessLevel[CamperAccessLevel["Banned"] = -1] = "Banned";
    CamperAccessLevel[CamperAccessLevel["Normal"] = 0] = "Normal";
    CamperAccessLevel[CamperAccessLevel["Firewatch"] = 1] = "Firewatch";
    CamperAccessLevel[CamperAccessLevel["Moderator"] = 2] = "Moderator";
    CamperAccessLevel[CamperAccessLevel["Admin"] = 3] = "Admin";
})(CamperAccessLevel || (CamperAccessLevel = {}));
export const CamperAccessLevelSchema = z.union([
    z.literal(CamperAccessLevel.Banned),
    z.literal(CamperAccessLevel.Normal),
    z.literal(CamperAccessLevel.Firewatch),
    z.literal(CamperAccessLevel.Moderator),
    z.literal(CamperAccessLevel.Admin),
]);
export const CamperPreferencesSchema = z.object({
    allowPings: z.boolean(),
    syncDiscordDisplayName: z.boolean(),
    tagline: TaglineStringSchema.nullable(),
    handle: CamperHandleSchema,
    displayName: CamperDisplayNameSchema,
    color: ColorStringSchema.nullable(),
    pronouns: PronounStringSchema.nullable(),
    email: EmailStringSchema.nullable(),
});
export const CamperChipSchema = z.object({
    id: z.number(),
    name: CamperDisplayNameSchema,
    handle: CamperHandleSchema,
    color: ColorStringSchema.nullable(),
    pronouns: PronounStringSchema.nullable(),
    avatarUrl: URLStringSchema.nullable(),
});
export const CamperSchema = CamperChipSchema.extend({
    id: z.number(),
    // Identity
    tagline: TaglineStringSchema.nullable(),
    websiteUrl: URLStringSchema.nullable(),
    email: EmailStringSchema.nullable(),
    // Preferences
    allowPings: z.boolean(),
    syncDiscordDisplayName: z.boolean(),
    // Timestampts
    createdAt: TimestampStringSchema,
    lastInteraction: TimestampStringSchema,
    // System
    role: CamperAccessLevelSchema,
}).readonly();
export const EventScopeSchema = z.union([
    z.array(z.number()),
    z.number(),
    z.literal("public"),
    z.literal("private").default("private"),
]);
export const GenericRelayEvent = z.object({
    eventName: z.string(),
    scope: EventScopeSchema,
    payload: z.unknown(),
});
export const MAX_TAGLINE_LENGTH = 120;
