import { z } from "zod";
import { CharacterSheetSchema, GameWorldSchema } from "../game";
import { CamperDisplayNameSchema, CamperHandleSchema, TimestampStringSchema, } from "../low/branded-primitives";
import { CamperSchema } from "../low/core";
import { DiscordIdentitySchema } from "./discord";
import { TwitchIdentitySchema } from "./twitch";
export const LodgeProfileSchema = z.object({
    camper: CamperSchema,
    sheet: CharacterSheetSchema,
    prose: z.string().nullable(),
    mastodon: z.string().nullable(),
    twitch: TwitchIdentitySchema.nullable(),
    discord: DiscordIdentitySchema.nullable(),
});
export const LodgeCommonPayloadSchema = z.object({
    camper: CamperSchema,
    sheet: CharacterSheetSchema,
    world: GameWorldSchema,
});
export const LodgeConnectedAccountsSchema = z.object({
    mastodon: z.string().nullable(),
    twitch: TwitchIdentitySchema.nullable(),
    discord: DiscordIdentitySchema.nullable(),
    prose: z.string().nullable(),
    mastoLink: z.string(),
});
export const EMPTY_LODGE_PROFILE = {
    camper: {
        id: -1,
        name: CamperDisplayNameSchema.parse("Loading..."),
        handle: CamperHandleSchema.parse("loading"),
        avatarUrl: null,
        lastInteraction: TimestampStringSchema.parse(new Date().toISOString()),
        createdAt: TimestampStringSchema.parse(new Date().toISOString()),
        tagline: null,
        websiteUrl: null,
        color: null,
        allowPings: false,
        syncDiscordDisplayName: false,
        role: 0,
        pronouns: null,
        email: null,
    },
    sheet: {
        camperId: -1,
        sheetId: -1,
        resources: {
            conduits: 0,
            silkwater: 0,
        },
        inventory: [],
        badges: [],
        flowers: [],
        concoctions: [],
        recipes: [],
    },
    discord: null,
    mastodon: null,
    twitch: null,
    prose: null,
};
