import { z } from "zod";
export declare const MAX_MAIL_LENGTH = 1000;
export declare const MailSchema: z.ZodObject<{
    id: z.ZodNumber;
    to: z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        handle: string & z.BRAND<"CamperHandle">;
        color: (string & z.BRAND<"ColorString">) | null;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    }, {
        handle: string;
        color: string | null;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    }>;
    from: z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        handle: string & z.BRAND<"CamperHandle">;
        color: (string & z.BRAND<"ColorString">) | null;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    }, {
        handle: string;
        color: string | null;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    }>;
    content: z.ZodString;
    read: z.ZodBoolean;
    createdAt: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    id: number;
    createdAt: number;
    content: string;
    to: {
        handle: string & z.BRAND<"CamperHandle">;
        color: (string & z.BRAND<"ColorString">) | null;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    };
    from: {
        handle: string & z.BRAND<"CamperHandle">;
        color: (string & z.BRAND<"ColorString">) | null;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    };
    read: boolean;
}, {
    id: number;
    createdAt: number;
    content: string;
    to: {
        handle: string;
        color: string | null;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    };
    from: {
        handle: string;
        color: string | null;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    };
    read: boolean;
}>;
export type Mail = z.infer<typeof MailSchema>;
/***********
 * ACTIONS *
 ***********/
export declare const MailRelayActions: {
    readonly "mail@send": {
        readonly input: z.ZodObject<{
            recipientId: z.ZodNumber;
            content: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            content: string;
            recipientId: number;
        }, {
            content: string;
            recipientId: number;
        }>;
        readonly output: z.ZodObject<{
            id: z.ZodNumber;
            to: z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                handle: string & z.BRAND<"CamperHandle">;
                color: (string & z.BRAND<"ColorString">) | null;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                handle: string;
                color: string | null;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>;
            from: z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                handle: string & z.BRAND<"CamperHandle">;
                color: (string & z.BRAND<"ColorString">) | null;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                handle: string;
                color: string | null;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>;
            content: z.ZodString;
            read: z.ZodBoolean;
            createdAt: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            id: number;
            createdAt: number;
            content: string;
            to: {
                handle: string & z.BRAND<"CamperHandle">;
                color: (string & z.BRAND<"ColorString">) | null;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            };
            from: {
                handle: string & z.BRAND<"CamperHandle">;
                color: (string & z.BRAND<"ColorString">) | null;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            };
            read: boolean;
        }, {
            id: number;
            createdAt: number;
            content: string;
            to: {
                handle: string;
                color: string | null;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            };
            from: {
                handle: string;
                color: string | null;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            };
            read: boolean;
        }>;
    };
    readonly "mail@read": {
        readonly input: z.ZodObject<{
            mailIds: z.ZodArray<z.ZodNumber, "many">;
        }, "strip", z.ZodTypeAny, {
            mailIds: number[];
        }, {
            mailIds: number[];
        }>;
        readonly output: z.ZodLiteral<true>;
    };
    readonly "mail@all-read": {
        readonly input: z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
        readonly output: z.ZodLiteral<true>;
    };
    readonly "mail@delete": {
        readonly input: z.ZodObject<{
            mailIds: z.ZodArray<z.ZodNumber, "many">;
        }, "strip", z.ZodTypeAny, {
            mailIds: number[];
        }, {
            mailIds: number[];
        }>;
        readonly output: z.ZodLiteral<true>;
    };
};
//# sourceMappingURL=mail.d.ts.map